<div align="center">
    <br><img src="https://github.com/ThiagoPanini/pynvest/blob/v0.0.x/docs/assets/gifs/logo-animated-intro.gif?raw=true" alt="pynvest-animated-intro">
</div>

<div align="center">  
  <br>
  
  [![PyPI](https://img.shields.io/pypi/v/pynvest?color=black)](https://pypi.org/project/pynvest/)
  ![PyPI - Downloads](https://img.shields.io/pypi/dm/pynvest?color=black)
  ![PyPI - Status](https://img.shields.io/pypi/status/pynvest?color=black)
  ![GitHub Last Commit](https://img.shields.io/github/last-commit/ThiagoPanini/pynvest?color=black)
  <br>

  ![CI workflow](https://img.shields.io/github/actions/workflow/status/ThiagoPanini/pynvest/ci-main.yml?label=ci)
  [![Documentation Status](https://readthedocs.org/projects/pynvest/badge/?version=latest)](https://pynvest.readthedocs.io/en/latest/?badge=latest)
  [![codecov](https://codecov.io/github/ThiagoPanini/pynvest/branch/main/graph/badge.svg?token=L4KO1RM63H)](https://codecov.io/github/ThiagoPanini/pynvest)

</div>

> **Note**
> Uma página de documentação está sendo construída para o pynvest no readthedocs. Acesse o seguinte link e veja o que há até o momento para essa biblioteca. Tão logo quanto possível, novas features serão adicionadas.

___

## Entre em contato comigo

- GitHub: [@ThiagoPanini](https://github.com/ThiagoPanini)
- LinkedIn: [Thiago Panini](https://www.linkedin.com/in/thiago-panini/)
- Hashnode: [panini-tech-lab](https://panini.hashnode.dev/)
- DevTo: [thiagopanini](https://dev.to/thiagopanini)